% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/evoper.R
\name{abm.pso}
\alias{abm.pso}
\title{abm.pso}
\usage{
abm.pso(objective, iterations = 100, iwc = 10, N = 20, phi1 = 2,
  phi2 = 2, W = 0)
}
\arguments{
\item{objective}{An instance of ObjectiveFunction (or subclass) class \link{ObjectiveFunction}}

\item{iterations}{The total number of interactions}

\item{iwc}{The maximun number of iteractions without changes in the output}

\item{N}{The Particle Swarm size}

\item{phi1}{Acceleration coefficient toward the previous best}

\item{phi2}{Acceleration coefficient toward the global best}

\item{W}{Inertia weight or Constriction coefficient}
}
\description{
An implementaion of Particle Swarm Optimization
method for parameter estimation of Individual-based models.
}
\examples{
\dontrun{
 f<- RepastFunction$new("c:/usr/models/BactoSim(HaldaneEngine-1.0)","ds::Output",300)

 f$addFactor(name="cyclePoint",min=0,max=90)
 f$addFactor(name="conjugationCost",min=0,max=100)
 f$addFactor(name="pilusExpressionCost",min=0,max=100)
 f$addFactor(name="gamma0",min=1,max=10)

 abm.pso(f, iwc= 10, iterations=100, N=20, phi1, phi2)
}

}
\references{
[1] Kennedy, J., & Eberhart, R. (1995). Particle swarm optimization.
In Proceedings of ICNN 95 - International Conference on Neural
Networks (Vol. 4, pp. 1942-1948). IEEE.

[2] Poli, R., Kennedy, J., & Blackwell, T. (2007). Particle swarm optimization.
Swarm Intelligence, 1(1), 33-57.
}

